OC.L10N.register(
    "core",
    {
    "Please select a file." : "Palun vali fail.",
    "File is too big" : "Fail on liiga suur",
    "The selected file is not an image." : "Valitud fail ei ole pilt.",
    "The selected file cannot be read." : "Valitud faili ei ole võimalik lugeda.",
    "Invalid file provided" : "Vigane fail",
    "No image or file provided" : "Ühtegi pilti või faili pole pakutud",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Invalid image" : "Vigane pilt",
    "An error occurred. Please contact your admin." : "Tekkis tõrge. Palun võta ühendust administraatoriga.",
    "No temporary profile picture available, try again" : "Ühtegi ajutist profiilipilti pole saadaval, proovi uuesti",
    "No crop data provided" : "Lõikeandmeid ei leitud",
    "No valid crop data provided" : "Kehtivaid lõikeandmeid pole leitud",
    "Crop is not square" : "Lõikamine pole ruudukujuline",
    "Password reset is disabled" : "Parooli taastamine on välja lülitatud",
    "Couldn't reset password because the token is invalid" : "Ei saanud parooli taastada, kuna märgend on vigane",
    "Couldn't reset password because the token is expired" : "Parooli ei saanud taastada, sest märgend on aegunud",
    "%s password reset" : "%s parooli lähtestus",
    "Password reset" : "Parooli taastamine ",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Kliki allolevale nupule, et taastada oma parool. Kui sa ei ole paroolitaastamist pärinud. siis ignoreeri seda e-kirja.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Kliki allolevale lingile, et taastada oma parool. Kui sa ei ole parooli taastamist pärinud. siis ignoreeri seda e-kirja.",
    "Reset your password" : "Lähtesta oma parool",
    "Preparing update" : "Uuendamise ettevalmistamine",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Palun kasutage uuendamiseks käsurida, kuna automaatne uuendamine on config.php failis välja lülitatud.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Kontrollin tabelit %s",
    "Turned on maintenance mode" : "Hooldusrežiim sisse lülitatud",
    "Turned off maintenance mode" : "Hooldusrežiim välja lülitatud",
    "Maintenance mode is kept active" : "Hooldusrežiim on aktiivne",
    "Updating database schema" : "Andmebaasi skeemi uuendamine",
    "Updated database" : "Uuendatud andmebaas",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Kontrollitakse, kas anembaasi skeemi saab uuendada (see võib võtta kaua aega olenevalt andmebaasi suurusest)",
    "Checked database schema update" : "Andmebaasi skeemi uuendus kontrollitud",
    "Checking updates of apps" : "Rakenduste uuenduste kontroll",
    "Checking for update of app \"%s\" in appstore" : "Rakenduse \"%s\" jaoks uuenduste kontrollimine rakenduste poes",
    "Update app \"%s\" from appstore" : "Uuenda rakendus \"%s\" rakenduste poes",
    "Checked for update of app \"%s\" in appstore" : "Kontrolliti uuendusi rakenduse \"%s\" jaoks rakenduste poes",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontrollitakse, kas %s andmebaasi skeemi saab uuendada (see võib võtta kaua aega sõltuvalt andmebaasi suuruses)",
    "Checked database schema update for apps" : "Andmebaasi skeemi uuendus rakendustele on kontrollitud",
    "Reset log level" : "Lähtesta logi tase",
    "Starting code integrity check" : "Koodi terviklikkuse kontrolli alustamine",
    "Finished code integrity check" : "Koodi terviklikkuse kontrolli lõpp",
    "%s (incompatible)" : "%s (pole ühilduv)",
    "Following apps have been disabled: %s" : "Järgnevad rakendused on välja lülitatud: %s",
    "Already up to date" : "On juba ajakohane",
    "Very weak password" : "Väga nõrk parool",
    "Weak password" : "Nõrk parool",
    "So-so password" : "Enam-vähem sobiv parool",
    "Good password" : "Hea parool",
    "Strong password" : "Väga hea parool",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Sinu veebiserver pole veel piisavalt korralikult seadistatud, et lubada failide sünkroniseerimist, kuna WebDAV liides paistab olevat katki.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Sinu veebiserver pole veel piisavalt korralikult seadistatud, et lahendada aadressi \"{url}\". Lisateavet leiate meie <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\"> dokumentatsioonist </a>.",
    "Error occurred while checking server setup" : "Serveri seadete kontrolimisel tekkis viga",
    "Non-existing tag #{tag}" : "Olematu silt #{tag}",
    "restricted" : "piiratud",
    "invisible" : "nähtamatu",
    "({scope})" : "({scope})",
    "Delete" : "Kustuta",
    "Rename" : "Nimeta ümber",
    "Collaborative tags" : "Koostöö sildid",
    "No tags found" : "Märgendeid ei leitud",
    "unknown text" : "tundmatu tekst",
    "Hello world!" : "Tere maailm!",
    "sunny" : "päikeseline",
    "Hello {name}, the weather is {weather}" : "Tere {name}, ilm on {weather}",
    "Hello {name}" : "Tere, {name}",
    "new" : "uus",
    "_download %n file_::_download %n files_" : ["laadi alla %n fail","laadi alla %n faili"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Värskendus on käimas, lahkudes sellelt lehelt võib protsessi mõnes keskkonnas katkestada.",
    "Update to {version}" : "Uuenda versioonile {version}",
    "An error occurred." : "Tekkis tõrge.",
    "Please reload the page." : "Palun laadi see uuesti.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uuendus ebaõnnestus. Täiendavat infot <a href=\"{url}\">vaata meie foorumi postituses</a> .",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uuendus ebaõnnestus. Palun teavita probleemist  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloudi kogukonda</a>.",
    "Continue to Nextcloud" : "Edasi Nextcloudi",
    "Searching other places" : "Otsi teistest kohtadest",
    "No search results in other folders for {tag}{filter}{endtag}" : "Teistest kaustadest ei leitud {tag}{filter}{endtag}",
    "Server side authentication failed!" : "Serveripoolne autentimine ebaõnnestus!",
    "Please contact your administrator." : "Palun kontakteeru oma süsteemihalduriga.",
    "An internal error occurred." : "Tekkis sisemine tõrge.",
    "Please try again or contact your administrator." : "Palun proovi uuesti või võta ühendust oma administraatoriga.",
    "Username or email" : "Kasutajanimi või e-posti aadress",
    "Password" : "Parool",
    "Log in" : "Logi sisse",
    "Logging in …" : "Sisselogimine ...",
    "Wrong username or password." : "Vale kasutajanimi või parool.",
    "User disabled" : "Kasutaja deaktiveeritud",
    "Reset password" : "Lähtesta parool",
    "Couldn't send reset email. Please contact your administrator." : "Ei suutnud lähtestada e-maili. Palun kontakteeru süsteemihalduriga.",
    "Password can not be changed. Please contact your administrator." : "Parooli ei saa muuta. Palun kontakteeru oma süsteemihalduriga.",
    "New password" : "Uus parool",
    "I know what I'm doing" : "Ma tean mida teen",
    "Cancel" : "Loobu",
    "Forgot password?" : "Unustasid parooli?",
    "Settings" : "Seaded",
    "Could not load your contacts" : "Sinu kontaktide laadimine ebaõnnestus",
    "Search contacts …" : "Otsi kontakte",
    "No contacts found" : "Kontakte ei leitud",
    "Show all contacts …" : "Näita kõiki kontakte",
    "Loading your contacts …" : "Sinu kontaktide laadimine ...",
    "Looking for {term} …" : "Otsin {term} …",
    "No" : "Ei",
    "Yes" : "Jah",
    "No files in here" : "Siin ei ole faile",
    "New folder" : "Uus kaust",
    "Name" : "Nimi",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "{newName} already exists" : "{newName} on juba olemas",
    "Choose" : "Vali",
    "Copy" : "Kopeeri",
    "Move" : "Liiguta",
    "Error loading file picker template: {error}" : "Viga failivalija malli laadimisel:  {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Viga sõnumi malli laadimisel: {error}",
    "read-only" : "kirjutuskaitstud",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failikonflikt","{count} failikonflikti"],
    "One file conflict" : "Üks failikonflikt",
    "New Files" : "Uued failid",
    "Already existing files" : "Juba olemasolevad failid",
    "Which files do you want to keep?" : "Milliseid faile sa soovid alles hoida?",
    "If you select both versions, the copied file will have a number added to its name." : "Kui valid mõlemad versioonid, siis lisatakse kopeeritud faili nimele number.",
    "Continue" : "Jätka",
    "(all selected)" : "(kõik valitud)",
    "({count} selected)" : "({count} valitud)",
    "Error loading file exists template" : "Viga faili olemasolu malli laadimisel",
    "Pending" : "Ootel",
    "Copy to {folder}" : "Kopeeri {folder}",
    "Move to {folder}" : "Liiguta {folder}",
    "Saving..." : "Salvestamine...",
    "Authentication required" : "Autentimine on vajalik",
    "This action requires you to confirm your password" : "See tegevus  nõuab parooli kinnitamist",
    "Confirm" : "Kinnita",
    "Failed to authenticate, try again" : "Autentimine ebaõnnestus, proovige uuesti",
    "seconds ago" : "sekundit tagasi",
    "Connection to server lost" : "Ühendus serveriga katkes",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Tõrge lehe laadimisel, ümberlaadimine  %n sekundi pärast","Tõrge lehe laadimisel, ümberlaadimine %n sekundi pärast"],
    "No action available" : "Ühtegi tegevust pole saadaval",
    "Error fetching contact actions" : "Viga kontakti toimingute laadimisel",
    "Personal" : "Isiklik",
    "Users" : "Kasutajad",
    "Apps" : "Rakendused",
    "Admin" : "Admin",
    "Help" : "Abiinfo",
    "Access forbidden" : "Ligipääs on keelatud",
    "File not found" : "Faili ei leitud",
    "Error" : "Viga",
    "Internal Server Error" : "Serveri sisemine viga",
    "The server was unable to complete your request." : "Server ei suutnud sinu päringut lõpetada.",
    "If this happens again, please send the technical details below to the server administrator." : "Kui see veel kord juhtub, saada tehnilised detailid allpool serveri administraatorile.",
    "More details can be found in the server log." : "Lisainfot võib leida serveri logist.",
    "Technical details" : "Tehnilised andmed",
    "Remote Address: %s" : "Kaugaadress: %s",
    "Request ID: %s" : "Päringu ID: %s",
    "Type: %s" : "Tüüp: %s",
    "Code: %s" : "Kood: %s",
    "Message: %s" : "Sõnum: %s",
    "File: %s" : "Fail: %s",
    "Line: %s" : "Rida: %s",
    "Trace" : "Jälita",
    "Security warning" : "Turvahoiatus",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su andmete kataloog ja failid on tõenäoliselt internetist vabalt saadaval kuna .htaccess fail ei toimi.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Serveri õigeks seadistamiseks leiate leiate infot <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentatsioonist</a>.",
    "Create an <strong>admin account</strong>" : "Loo <strong>admini konto</strong>",
    "Username" : "Kasutajanimi",
    "Storage & database" : "Andmehoidla ja andmebaas",
    "Data folder" : "Andmete kaust",
    "Configure the database" : "Seadista andmebaasi",
    "Only %s is available." : "Ainult %s on saadaval.",
    "Install and activate additional PHP modules to choose other database types." : "Paigalda ja aktiveeri täiendavaid PHP mooduleid, et teisi andmebaasi tüüpe valida.",
    "For more details check out the documentation." : "Lisainfot vaata dokumentatsioonist.",
    "Database user" : "Andmebaasi kasutaja",
    "Database password" : "Andmebaasi parool",
    "Database name" : "Andmebasi nimi",
    "Database tablespace" : "Andmebaasi tabeliruum",
    "Database host" : "Andmebaasi host",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Palun sisesta pordi number koos hostinimega (nt. localhost: 5432).",
    "Performance warning" : "Kiiruse hoiatus",
    "Finish setup" : "Lõpeta seadistamine",
    "Finishing …" : "Lõpetamine ...",
    "Need help?" : "Vajad abi?",
    "See the documentation" : "Vaata dokumentatsiooni",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "See rakendus vajab toimimiseks JavaScripti. Palun {linkstart}luba JavaScript{linkend} ning laadi see leht uuesti.",
    "More apps" : "Veel rakendusi",
    "More" : "Rohkem",
    "Search" : "Otsi",
    "Reset search" : "Lähtesta otsing",
    "Contacts" : "Kontaktid",
    "Confirm your password" : "Kinnita oma parool",
    "Grant access" : "Anna ligipääs",
    "Account access" : "Konto ligipääs",
    "This share is password-protected" : "See jagamine on parooliga kaitstud",
    "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
    "Two-factor authentication" : "Kaheastmeline autentimine",
    "Use backup code" : "Kasuta varu koodi",
    "Error while validating your second factor" : "Teise faktori valideerimise viga",
    "Access through untrusted domain" : "Ligipääs läbi ebausaldusväärse domeeni",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Palun võtke ühendust oma administraatoriga. Kui olete administraator, muutke konfiguratsioonis config/config.php sätet \"trusted_domains\", nagu näidis config.sample.php failis.",
    "App update required" : "Rakenduse uuendus on nõutud",
    "These apps will be updated:" : "Neid rakendusi uuendatakse:",
    "These incompatible apps will be disabled:" : "Need mitteühilduvad rakendused lülitatakse välja:",
    "The theme %s has been disabled." : "Teema %s on keelatud.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Enne jätkamist veendu, et andmebaas, seadete ning andmete kataloog on varundatud.",
    "Start update" : "Käivita uuendus",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Suurtel saitidel aegumise vältimiseks võid sa paigalduskaustas käivitada järgmise käsu:",
    "Detailed logs" : "Üksikasjalikud logid",
    "Update needed" : "Uuendamine vajaliik",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Palun kasutage uuendamiseks käsurida, kuna teil on suur instants rohkem kui 50 kasutajaga.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Abi saamiseks vaata <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentatsiooni</a>.",
    "Upgrade via web on my own risk" : "Uuenda veebi kaudu omal vastutusel",
    "This %s instance is currently in maintenance mode, which may take a while." : "See %s instants on hetkel haldusrežiimis, mis võib kesta mõnda aega.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakteeru oma süsteemihalduriga, kui see teade püsib või on tekkinud ootamatult.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Ei saanud saata lähtestamise e-kirja kuna antud kasutajal puudub e-posti aadress. Palun kontakteeruge administraatoriga ",
    "Couldn't send reset email. Please make sure your username is correct." : "Ei suutnud lähtestada e-maili. Palun veendu, et kasutajatunnus on õige.",
    "Dismiss" : "Jäta vahele",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Link parooli vahetuseks on saadetud Sinu e-posti aadressil.<br>Kui kiri pole saabunud mõistliku aja jooksul, siis kontrolli oma spam-/rämpskirjade katalooge<br>.Kui kirja pole ka seal, siis küsi abi süsteemihaldurilt.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Sinu failid on krüpteeritud. Andmete taaastaamine ei ole pärast parooli lähtestaamist enam võimalik. <br />Kui Sa ei ole kindel mida teha, kontakteeru palun enne jätkamist administraatoriga. <br />Kas Sa kindlasti soovid jätkata?",
    "Sending email …" : "Saadan kirja ...",
    "Shared" : "Jagatud",
    "Shared with" : "Jagatud",
    "Shared by" : "Jagas",
    "Choose a password for the public link" : "Vali avaliku lingi jaoks parool",
    "Choose a password for the public link or press the \"Enter\" key" : "Vali avaliku lingi jaoks parool või vajuta klahvi \"Enter\"",
    "Copied!" : "Kopeeritud!",
    "Copy link" : "Kopeeri link",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘ + C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl + C.",
    "Resharing is not allowed" : "Edasijagamine pole lubatud",
    "Link" : "Link",
    "Password protect" : "Parooliga kaitstud",
    "Allow editing" : "Luba muutmine",
    "Email link to person" : "Saada link isikule e-postiga",
    "Send" : "Saada",
    "Allow upload and editing" : "Luba üleslaadimine ja muutmine",
    "Read only" : "kirjutuskaitstud",
    "File drop (upload only)" : "Faili lohistamine (ainult üleslaadimine)",
    "Set expiration date" : "Määra aegumise kuupäev",
    "Expiration" : "Aegumine",
    "Expiration date" : "Aegumise kuupäev",
    "Unshare" : "Lõpeta jagamine",
    "Share to {name}" : "Jaga kasutajale {name}",
    "Share link" : "Jaga linki",
    "Could not unshare" : "Jagamise lõpetamine ebaõnnestus",
    "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja {group} grupiga {owner} poolt",
    "Shared with you by {owner}" : "Sinuga jagas {owner}",
    "Choose a password for the mail share" : "Vali parool e-postiga jagamisel",
    "group" : "grupp",
    "remote" : "kaug",
    "email" : "e-post",
    "shared by {sharer}" : "jagatud kasutajalt {sharer}",
    "Can reshare" : "Võib edasi jagada",
    "Can edit" : "Võib redigeerida",
    "Can create" : "Võib luua",
    "Can change" : "Võib muuta",
    "Can delete" : "Võib kustutada",
    "Access control" : "Ligipääsukontroll",
    "Error while sharing" : "Viga jagamisel",
    "Share details could not be loaded for this item." : "Selle üksuse jagamise detaile ei õnnestunud laadida.",
    "This list is maybe truncated - please refine your search term to see more results." : "See nimekiri võib olla kärbitud - palun täpsusta oma otsingut, et näha rohkem tulemusi.",
    "No users or groups found for {search}" : "Otsingu {search} põhjal kasutajaid ega gruppe ei leitud",
    "No users found for {search}" : "Otsingu {search} põhjal kasutajaid ei leitud",
    "An error occurred (\"{message}\"). Please try again" : "Tekkis tõrge (\"{message}\"). Palun proovi uuesti.",
    "An error occurred. Please try again" : "Tekkis tõrge. Palun proovi uuesti",
    "Home" : "Avaleht",
    "Work" : "Töö",
    "Other" : "Muu",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Jaga",
    "Name or email address..." : "Nimi või e-posti aadress",
    "Name or federated cloud ID..." : "Liitpilve nimi või ID...",
    "Name, federated cloud ID or email address..." : "Liitpilve nimi, ID või e-posti aadress...",
    "Name..." : "Nimi...",
    "Error removing share" : "Viga jagamise eemaldamisel",
    "SQLite will be used as database." : "Andmebaasina kasutatakse SQLite",
    "For larger installations we recommend to choose a different database backend." : "Suuremate paigalduste jaoks soovitame valida teise andmebaasi.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Eriti kui tasutad töölaua rakendust failide sünkroonimiseks on SQLite andmebaas ebasoovitav.",
    "Wrong password." : "Vale parool.",
    "New Password" : "Uus parool",
    "Cancel log in" : "Katkesta sisselogimine"
},
"nplurals=2; plural=(n != 1);");
